@@ -1,4 +1,5 @@
 """Test utils for ansible-lint."""
+
 from __future__ import annotations
 
 import os
@@ -13,7 +14,6 @@ from ansiblelint.app import get_app
 
 if TYPE_CHECKING:
     # https://github.com/PyCQA/pylint/issues/3240
-    # pylint: disable=unsubscriptable-object
     CompletedProcess = subprocess.CompletedProcess[Any]
     from ansiblelint.errors import MatchError
     from ansiblelint.rules import RulesCollection
@@ -34,7 +34,7 @@ class RunFromText:
         # Emulate command line execution initialization as without it Ansible module
         # would be loaded with incomplete module/role/collection list.
         if not self.app:  # pragma: no cover
-            self.app = get_app()
+            self.app = get_app(offline=True)
 
         self.collection = collection
 
@@ -156,4 +156,5 @@ def run_ansible_lint(
         cwd=cwd,
         env=_env,
         text=True,
+        encoding="utf-8",
     )
